<?php

add_filter('get_avatar_url', 'jxpress_user_avatars_filter_get_avatar_url', 10, 3);

function jxpress_user_avatars_filter_get_avatar_url($url, $id_or_email, $args) {

    // Bail if forcing default
    if (!empty($args['force_default'])) {
        return $url;
    }

    // Bail if explicitly an md5'd Gravatar url
    // https://github.com/stuttter/wp-user-avatars/issues/11
    if (is_string($id_or_email) && strpos($id_or_email, '@md5.gravatar.com')) {
        return $url;
    }

    // Look for local avatar
    $avatar = jxpress_user_avatars_get_local_avatar_url($id_or_email, $args['size']);

    // Override URL if avatar is found
    if (!empty($avatar)) {
        $url = $avatar;
    }

    // Return maybe-local URL
    return $url;
}

function jxpress_user_avatars_get_user_id($id_or_email) {

    // Default
    $retval = 0;

    // Numeric, so use ID
    if (is_numeric($id_or_email)) {
        $retval = $id_or_email;

        // Maybe email or login
    } elseif (is_string($id_or_email)) {

        // User by
        $user_by = is_email($id_or_email) ? 'email' : 'login';

        // Get user
        $user = get_user_by($user_by, $id_or_email);

        // User ID
        if (!empty($user)) {
            $retval = $user->ID;
        }

        // User Object
    } elseif ($id_or_email instanceof WP_User) {
        $user = $id_or_email->ID;

        // Post Object
    } elseif ($id_or_email instanceof WP_Post) {
        $retval = $id_or_email->post_author;

        // Comment
    } elseif ($id_or_email instanceof WP_Comment) {
        if (!empty($id_or_email->user_id)) {
            $retval = $id_or_email->user_id;
        }
    }

    return (int) apply_filters('jxpress_user_avatars_get_user_id', (int) $retval, $id_or_email);
}

function jxpress_count_posts_by_author($user_id, $post_type) {
    global $wp_query;
    $args = array(
        'post_type' => $post_type,
        'author' => $user_id,
        'posts_per_page' => -1 // no limit
    );
    echo count(get_posts($args));
}

function jxpress_user_avatars_get_local_avatar_url($user_id = false, $size = 250) {

    // Try to get user ID
    $user_id = jxpress_user_avatars_get_user_id($user_id);

    // Bail if no user ID
    if (empty($user_id)) {
        return null;
    }

    // Fetch avatars from usermeta, bail if no full option
    $user_avatars = get_user_meta($user_id, 'wp_user_avatars', true);
    if (empty($user_avatars['full'])) {
        return null;
    }

    // Get ratings
    $avatar_rating = get_user_meta($user_id, 'wp_user_avatars_rating', true);
    $site_rating = get_option('avatar_rating', 'G');
    $switched = false;

    // Compare ratings
    if (!empty($avatar_rating) && ( 'G' !== $avatar_rating ) && ( $avatar_rating !== $site_rating )) {

        // Calculate rating weights
        $ratings = wp_user_avatars_get_ratings();
        $ratings_key = array_keys($ratings);
        $site_rating_weight = array_search($site_rating, $ratings_key);
        $avatar_rating_weight = array_search($avatar_rating, $ratings_key);

        // Too risky
        if (( false !== $avatar_rating_weight ) && ( $avatar_rating_weight > $site_rating_weight )) {
            return null;
        }
    }

    // Maybe switch to blog
    if (isset($user_avatars['site_id']) && is_multisite()) {
        $switched = true;
        switch_to_blog($user_avatars['site_id']);
    }

    // Handle "real" media
    if (!empty($user_avatars['media_id'])) {

        // Has the media been deleted?
        $avatar_full_path = get_attached_file($user_avatars['media_id']);

        // Maybe return null & maybe delete the avatar setting
        if (empty($avatar_full_path)) {

            // Only let logged in users delete missing avatars
            if (is_user_logged_in()) {
                // wp_user_avatars_delete_avatar($user_id);
            }

            // Maybe switch back
            if (true === $switched) {
                restore_current_blog();
            }

            return null;
        }
    }

    // Generate a new size
    if (empty($user_avatars[$size])) {

        // Set full size
        $user_avatars[$size] = $user_avatars['full'];

        // Allow rescaling to be toggled, usually for performance reasons
        if (apply_filters('wp_user_avatars_dynamic_resize', true)) {

            // Get the upload path (hard to trust this sometimes, though...)
            $upload_path = wp_upload_dir();

            // Get path for image by converting URL
            if (!isset($avatar_full_path)) {
                $avatar_full_path = str_replace($upload_path['baseurl'], $upload_path['basedir'], $user_avatars['full']);
            }

            // Load image editor (for resizing)
            $editor = wp_get_image_editor($avatar_full_path);
            if (!is_wp_error($editor)) {

                // Attempt to resize
                $resized = $editor->resize($size, $size, true);
                if (!is_wp_error($resized)) {

                    $dest_file = $editor->generate_filename();
                    $saved = $editor->save($dest_file);

                    if (!is_wp_error($saved)) {
                        $user_avatars[$size] = str_replace($upload_path['basedir'], $upload_path['baseurl'], $dest_file);
                    }
                }
            }

            // Save updated avatar sizes
            update_user_meta($user_id, 'wp_user_avatars', $user_avatars);
        }
    }

    // URL corrections
    if ('http' !== substr($user_avatars[$size], 0, 4)) {
        $user_avatars[$size] = home_url($user_avatars[$size]);
    }

    // Maybe switch back
    if (true === $switched) {
        restore_current_blog();
    }

    // Return the url
    return $user_avatars[$size];
}

add_action('wp_ajax_nopriv_candidateprofile', 'jxpress_candidateprofile');
add_action('wp_ajax_candidateprofile', 'jxpress_candidateprofile');

function jxpress_candidateprofile() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidateprofile-nonce', 'security');

    if (!function_exists('wp_handle_upload')) {
        require_once( ABSPATH . 'wp-admin/includes/file.php' );
    }

    if (!empty($_FILES['user_avtar']["name"])) {
        $file_data = isset($_FILES) ? $_FILES : array();
        $GLOBALS['wp_user_avatars_user_id'] = $user_id;
        $avatar = wp_handle_upload($_FILES['user_avtar'], array(
            'mimes' => array(
                'jpg|jpeg|jpe' => 'image/jpeg',
                'gif' => 'image/gif',
                'png' => 'image/png',
            ),
            'test_form' => false,
            'unique_filename_callback' => 'wp_user_avatars_unique_filename_callback'
        ));



        if (isset($avatar ["file"])) {
            $file_name_and_location = $avatar ["file"];
            $file_title_for_media_library = $title;

            $attachment = array(
                "post_mime_type" => $avatar['type'],
                "post_title" => addslashes($file_title_for_media_library),
                "post_content" => "",
                "post_status" => "inherit"
            );

            if (!is_null($post)) {
                if (!is_numeric($post)) {
                    $post = $post->ID;
                } // if ()

                $attachment ['post_parent'] = $post;
            } // if ()

            $id = wp_insert_attachment($attachment, $file_name_and_location);

            require_once( ABSPATH . "wp-admin/includes/image.php" );

            $attach_data = wp_generate_attachment_metadata($id, $file_name_and_location);
            wp_update_attachment_metadata($id, $attach_data);
        }



        // Setup empty meta array
        $meta_value = array();
        // Set the attachment URL
        if (is_int($avatar['url'])) {
            $meta_value['media_id'] = $avatar['url'];
            $meta_value['site_id'] = get_current_blog_id();
            $media = wp_get_attachment_url($avatar['url']);
        }
        // Set full value to media URL
        $meta_value['full'] = esc_url_raw($avatar['url']);
        update_user_meta($user_id, 'wp_full_avatars', $meta_value['full']);
        update_user_meta($user_id, 'wp_user_avatars', $meta_value);
    }
    $FirtName = isset($_POST['user_fname']) ? sanitize_text_field($_POST['user_fname']) : '';
    $LastName = isset($_POST['user_lname']) ? sanitize_text_field($_POST['user_lname']) : '';
    $userdata = array(
        'ID' => $user_id,
        'user_url'     => isset($_POST['user_url']) ? esc_url_raw($_POST['user_url']) : '',
        'first_name'   => isset($_POST['user_fname']) ? sanitize_text_field($_POST['user_fname']) : '',
        'last_name'    => isset($_POST['user_lname']) ? sanitize_text_field($_POST['user_lname']) : '',
        'description'  => isset($_POST['user_description']) ? $_POST['user_description'] : '',
        'user_email'   => isset($_POST['user_email']) ? sanitize_email($_POST['user_email']) : '',
        'display_name' =>  $FirtName.' '.$LastName,
    );
    $usr = wp_update_user($userdata);

    if (isset($_POST['user_title']))
        update_user_meta($user_id, 'user_title', sanitize_text_field($_POST['user_title']));

    if (isset($_POST['user_category']))
        update_user_meta($user_id, 'user_category', sanitize_text_field($_POST['user_category']));

    if (isset($_POST['user_facebook']))
        update_user_meta($user_id, 'user_facebook', sanitize_text_field($_POST['user_facebook']));

    if (isset($_POST['user_twitter']))
        update_user_meta($user_id, 'user_twitter', sanitize_text_field($_POST['user_twitter']));

    if (isset($_POST['user_linkedin']))
        update_user_meta($user_id, 'user_linkedin', sanitize_text_field($_POST['user_linkedin']));

    if (isset($_POST['user_google']))
        update_user_meta($user_id, 'user_google', sanitize_text_field($_POST['user_google']));

    if (isset($_POST['user_youtube_video']))
        update_user_meta($user_id, 'user_youtube_video', sanitize_text_field($_POST['user_youtube_video']));

    if (isset($_POST['user_vimeo_video']))
        update_user_meta($user_id, 'user_vimeo_video', sanitize_text_field($_POST['user_vimeo_video']));


    if (isset($_POST['user_phone']))
        update_user_meta($user_id, 'user_phone', sanitize_text_field($_POST['user_phone']));

    if (isset($_POST['user_country']))
        update_user_meta($user_id, 'user_country', sanitize_text_field($_POST['user_country']));

    if (isset($_POST['user_city']))
        update_user_meta($user_id, 'user_city', sanitize_text_field($_POST['user_city']));

    if (isset($_POST['user_address']))
        update_user_meta($user_id, 'user_address', sanitize_textarea_field($_POST['user_address']));

    if (isset($_POST['user_experience']))
        update_user_meta($user_id, 'user_experience', sanitize_text_field($_POST['user_experience']));

    if (isset($_POST['user_languages']))
        update_user_meta($user_id, 'user_languages', sanitize_text_field(json_encode($_POST['user_languages'])));

    if (isset($_POST['user_current_salary']))
        update_user_meta($user_id, 'user_current_salary', sanitize_text_field($_POST['user_current_salary']));

    if (isset($_POST['user_expected_salary']))
        update_user_meta($user_id, 'user_expected_salary', sanitize_text_field($_POST['user_expected_salary']));

    if (isset($_POST['user_qualification']))
        update_user_meta($user_id, 'user_qualification', sanitize_text_field(json_encode($_POST['user_qualification'])));

    if (isset($_POST['user_age']))
        update_user_meta($user_id, 'user_age', sanitize_text_field($_POST['user_age']));


    if (isset($_POST['user_latitude']))
        update_user_meta($user_id, 'user_latitude', sanitize_text_field($_POST['user_latitude']));
    if (isset($_POST['user_longitude']))
        update_user_meta($user_id, 'user_longitude', sanitize_text_field($_POST['user_longitude']));

    update_user_meta($user_id, 'profile_completed', 1);

    if (is_wp_error($usr)) {
        $error = $usr->get_error_codes();
        if (in_array('existing_user_email', $error)) {
            echo json_encode(array('message' => __($usr->get_error_message('existing_user_email'), 'jxpress-portal')));
        } else {
            echo json_encode(array('message' => __('Profile Updated Successfully.', 'jxpress-portal')));
        }
    } else {
        echo json_encode(array('message' => __('Profile Updated Successfully.', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_candidatecv', 'jxpress_candidatecv');
add_action('wp_ajax_candidatecv', 'jxpress_candidatecv');

function jxpress_candidatecv() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidatecv-nonce', 'security');
    if (!function_exists('wp_handle_upload')) {
        require_once( ABSPATH . 'wp-admin/includes/file.php' );
    }

    if (!empty($_FILES['user_cv']["name"])) {
        $file_data = isset($_FILES) ? $_FILES : array();
        $avatar = wp_handle_upload($_FILES['user_cv'], array(
            'mimes' => array(
                'doc' => 'application/msword',
                'docx' => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
                'pdf' => 'application/pdf',
                'rtf' => 'application/rtf',
            ),
            'test_form' => false
        ));

        if (!empty($avatar['url'])) {
            update_user_meta($user_id, 'user_cv', $avatar['url']);
        }
    } else {
        if (isset($_POST['current_cv']))
            update_user_meta($user_id, 'user_cv', sanitize_text_field($_POST['current_cv']));
    }
    if (isset($_POST['user_coverletter']))
        update_user_meta($user_id, 'user_coverletter', $_POST['user_coverletter']);
    echo json_encode(array('message' => __('CV Updated Successfully.', 'jxpress-portal')));
    die();
}

add_action('wp_ajax_nopriv_candidateeducation', 'jxpress_candidateeducation');
add_action('wp_ajax_candidateeducation', 'jxpress_candidateeducation');

function jxpress_candidateeducation() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidateeducation-nonce', 'security');
    $education = array('education_title' => $_POST['education_title'],
        'education_from' => $_POST['education_from'],
        'education_to' => $_POST['education_to'],
        'education_institute' => $_POST['education_institute'],
        'education_description' => $_POST['education_description']);
    $educationstring = json_encode($education);
    if (isset($_POST['umetaid'])) {
        update_metadata_by_mid('user', $_POST['umetaid'], $educationstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Education Updated Successfully.', 'jxpress-portal')));
    } else {
        add_user_meta($user_id, 'user_educations', $educationstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Education Added Successfully.', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_candidateexperience', 'jxpress_candidateexperience');
add_action('wp_ajax_candidateexperience', 'jxpress_candidateexperience');

function jxpress_candidateexperience() {
    global $current_user;
    $user_id = get_current_user_id();

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidateexperience-nonce', 'security');
    $experience = array('experience_company' => $_POST['experience_company'],
        'experience_from' => $_POST['experience_from'],
        'experience_to' => $_POST['experience_present'] ? "Present" : $_POST['experience_to'],
        'experience_present' => $_POST['experience_present'],
        'experience_description' => $_POST['experience_description']);
    $experiencestring = json_encode($experience);
    if (isset($_POST['umetaid'])) {
        update_metadata_by_mid('user', $_POST['umetaid'], $experiencestring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Experiences Updated Successfully.', 'jxpress-portal')));
    } else {
        add_user_meta($user_id, 'user_experiences', $experiencestring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Experiences Added Successfully.', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_candidateskill', 'jxpress_candidateskill');
add_action('wp_ajax_candidateskill', 'jxpress_candidateskill');

function jxpress_candidateskill() {
    global $current_user;
    $user_id = get_current_user_id();

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidateskill-nonce', 'security');
    $skill = array('skill_title' => $_POST['skill_title'],
        'skill_percentage' => $_POST['skill_percentage']);
    $skillstring = json_encode($skill);
    if (isset($_POST['umetaid'])) {
        update_metadata_by_mid('user', $_POST['umetaid'], $skillstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Skill Updated Successfully.', 'jxpress-portal')));
    } else {
        add_user_meta($user_id, 'user_skills', $skillstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Skill Added Successfully.', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_candidateaward', 'jxpress_candidateaward');
add_action('wp_ajax_candidateaward', 'jxpress_candidateaward');

function jxpress_candidateaward() {
    global $current_user;
    $user_id = get_current_user_id();

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidateaward-nonce', 'security');
    $award = array('award_title' => $_POST['award_title'],
        'award_year' => $_POST['award_year'],
        'award_description' => $_POST['award_description']);
    $awardstring = json_encode($award);
    if (isset($_POST['umetaid'])) {
        update_metadata_by_mid('user', $_POST['umetaid'], $awardstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Award Updated Successfully.', 'jxpress-portal')));
    } else {
        add_user_meta($user_id, 'user_awards', $awardstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Award Added Successfully.', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_candidatework', 'jxpress_candidatework');
add_action('wp_ajax_candidatework', 'jxpress_candidatework');

function jxpress_candidatework() {
    global $current_user;
    $user_id = get_current_user_id();

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-candidatework-nonce', 'security');

    $image = "";
    if (!function_exists('wp_handle_upload')) {
        require_once( ABSPATH . 'wp-admin/includes/file.php' );
    }

    if (!empty($_FILES['work_image']["name"])) {
        $file_data = isset($_FILES) ? $_FILES : array();
        $avatar = wp_handle_upload($_FILES['work_image'], array(
            'mimes' => array(
                'jpg|jpeg|jpe' => 'image/jpeg',
                'gif' => 'image/gif',
                'png' => 'image/png',
            ),
            'test_form' => false
        ));

        if (isset($avatar ["file"])) {
            $file_name_and_location = $avatar ["file"];
            $file_title_for_media_library = $title;

            $attachment = array(
                "post_mime_type" => $avatar['type'],
                "post_title" => addslashes($file_title_for_media_library),
                "post_content" => "",
                "post_status" => "inherit"
            );

            if (!is_null($post)) {
                if (!is_numeric($post)) {
                    $post = $post->ID;
                } // if ()

                $attachment ['post_parent'] = $post;
            } // if ()

            $id = wp_insert_attachment($attachment, $file_name_and_location);

            require_once( ABSPATH . "wp-admin/includes/image.php" );

            $attach_data = wp_generate_attachment_metadata($id, $file_name_and_location);
            wp_update_attachment_metadata($id, $attach_data);
        }


        if (!empty($avatar['url'])) {
            $image = $avatar['url'];
        }
    } else {
        if (isset($_POST['old_image'])) {
            $image = $_POST['old_image'];
        }
    }


    $work = array('work_title' => $_POST['work_title'],
        'work_url' => $_POST['work_url'],
        'work_image' => $image);
    $workstring = json_encode($work);
    if (isset($_POST['umetaid'])) {
        update_metadata_by_mid('user', $_POST['umetaid'], $workstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Work Updated Successfully.', 'jxpress-portal')));
    } else {
        add_user_meta($user_id, 'user_works', $workstring);
        echo json_encode(array('url' => $_POST['_wp_http_referer'], 'message' => __('Work Added Successfully.', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_candidatedeleteusermeta', 'jxpress_candidatedeletemeta');
add_action('wp_ajax_candidatedeleteusermeta', 'jxpress_candidatedeletemeta');

function jxpress_candidatedeletemeta() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    if (isset($_POST['umetaid'])) {
        delete_metadata_by_mid('user', $_POST['umetaid']);
        echo json_encode(array( 'status' => 'removed', 'message' => __('Data deleted successfully.', 'jxpress-portal')));
    }

    die();
}

add_action('wp_ajax_nopriv_deleteuserfavJobs', 'jxpress_deleteuserfavJobs');
add_action('wp_ajax_deleteuserfavJobs', 'jxpress_deleteuserfavJobs');

function jxpress_deleteuserfavJobs() {
    global $current_user;
    $user_id  = get_current_user_id();

    if (isset($_POST['delidjob'])) {
        $delidjob = isset( $_POST['delidjob'] ) ? $_POST['delidjob'] : '';
        global $wpdb;   
        $wpdb->query( 'DELETE  FROM '.$wpdb->prefix.'usermeta where user_id = "'.$user_id.'" and meta_key = "job_shortlist" and meta_value = "'.$delidjob.'"' );
        echo json_encode(array( 'status' => 'removed', 'message' => __('Job Removed Successfully.', 'jxpress-portal')));
    }

    die();
}

add_action('wp_ajax_nopriv_employerprofile', 'jxpress_employerprofile');
add_action('wp_ajax_employerprofile', 'jxpress_employerprofile');

function jxpress_employerprofile() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-employerprofile-nonce', 'security');

    if (!function_exists('wp_handle_upload')) {
        require_once( ABSPATH . 'wp-admin/includes/file.php' );
    }

    if (!empty($_FILES['user_avtar']["name"])) {
        $file_data = isset($_FILES) ? $_FILES : array();
        $GLOBALS['wp_user_avatars_user_id'] = $user_id;
        $avatar = wp_handle_upload($_FILES['user_avtar'], array(
            'mimes' => array(
                'jpg|jpeg|jpe' => 'image/jpeg',
                'gif' => 'image/gif',
                'png' => 'image/png',
            ),
            'test_form' => false,
            'unique_filename_callback' => 'wp_user_avatars_unique_filename_callback'
        ));

        if (isset($avatar ["file"])) {
            $file_name_and_location = $avatar ["file"];
            $file_title_for_media_library = $title;

            $attachment = array(
                "post_mime_type" => $avatar['type'],
                "post_title" => addslashes($file_title_for_media_library),
                "post_content" => "",
                "post_status" => "inherit"
            );

            if (!is_null($post)) {
                if (!is_numeric($post)) {
                    $post = $post->ID;
                } // if ()

                $attachment ['post_parent'] = $post;
            } // if ()

            $id = wp_insert_attachment($attachment, $file_name_and_location);

            require_once( ABSPATH . "wp-admin/includes/image.php" );

            $attach_data = wp_generate_attachment_metadata($id, $file_name_and_location);
            wp_update_attachment_metadata($id, $attach_data);
        }

        // Setup empty meta array
        $meta_value = array();
        // Set the attachment URL
        if (is_int($avatar['url'])) {
            $meta_value['media_id'] = $avatar['url'];
            $meta_value['site_id'] = get_current_blog_id();
            $media = wp_get_attachment_url($avatar['url']);
        }
        // Set full value to media URL
        $meta_value['full'] = esc_url_raw($avatar['url']);
        update_user_meta($user_id, 'wp_full_avatars', $meta_value['full']);
        update_user_meta($user_id, 'wp_user_avatars', $meta_value);
    }
    $userdata = array(
        'ID' => $user_id,
        'user_url' => isset($_POST['user_url']) ? esc_url_raw($_POST['user_url']) : '',
        'display_name' => isset($_POST['display_name']) ? sanitize_text_field($_POST['display_name']) : '',
        'description' => isset($_POST['user_description']) ? $_POST['user_description'] : '',
        'user_email' => isset($_POST['user_email']) ? sanitize_email($_POST['user_email']) : '',
    );
    $usr = wp_update_user($userdata);

    if (isset($_POST['user_category']))
        update_user_meta($user_id, 'user_category', sanitize_text_field($_POST['user_category']));

    if (isset($_POST['user_facebook']))
        update_user_meta($user_id, 'user_facebook', sanitize_text_field($_POST['user_facebook']));

    if (isset($_POST['user_twitter']))
        update_user_meta($user_id, 'user_twitter', sanitize_text_field($_POST['user_twitter']));

    if (isset($_POST['user_linkedin']))
        update_user_meta($user_id, 'user_linkedin', sanitize_text_field($_POST['user_linkedin']));

    if (isset($_POST['user_google']))
        update_user_meta($user_id, 'user_google', sanitize_text_field($_POST['user_google']));

    if (isset($_POST['user_youtube_video']))
        update_user_meta($user_id, 'user_youtube_video', sanitize_text_field($_POST['user_youtube_video']));

    if (isset($_POST['user_vimeo_video']))
        update_user_meta($user_id, 'user_vimeo_video', sanitize_text_field($_POST['user_vimeo_video']));


    if (isset($_POST['user_phone']))
        update_user_meta($user_id, 'user_phone', sanitize_text_field($_POST['user_phone']));

    if (isset($_POST['user_country']))
        update_user_meta($user_id, 'user_country', sanitize_text_field($_POST['user_country']));

    if (isset($_POST['user_city']))
        update_user_meta($user_id, 'user_city', sanitize_text_field($_POST['user_city']));

    if (isset($_POST['user_address']))
        update_user_meta($user_id, 'user_address', sanitize_textarea_field($_POST['user_address']));

    if (isset($_POST['user_since']))
        update_user_meta($user_id, 'user_since', sanitize_text_field($_POST['user_since']));

    if (isset($_POST['user_teamsize']))
        update_user_meta($user_id, 'user_teamsize', sanitize_text_field($_POST['user_teamsize']));

    if (isset($_POST['user_business_type']))
        update_user_meta($user_id, 'user_business_type', sanitize_text_field($_POST['user_business_type']));

    if (isset($_POST['user_latitude']))
        update_user_meta($user_id, 'user_latitude', sanitize_text_field($_POST['user_latitude']));
    if (isset($_POST['user_longitude']))
        update_user_meta($user_id, 'user_longitude', sanitize_text_field($_POST['user_longitude']));

    update_user_meta($user_id, 'profile_completed', 1);


    if (is_wp_error($usr)) {
        $error = $usr->get_error_codes();
        if (in_array('existing_user_email', $error)) {
            echo json_encode(array('message' => __($usr->get_error_message('existing_user_email'), 'jxpress-portal')));
        } else {
            echo json_encode(array('message' => __('Profile Updated Successfully.', 'jxpress-portal', 'jxpress-portal')));
        }
    } else {
        echo json_encode(array('message' => __('Profile Updated Successfully.', 'jxpress-portal', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_jobpost', 'jxpress_jobpost');
add_action('wp_ajax_jobpost', 'jxpress_jobpost');

function jxpress_jobpost() {
    global $current_user;
    $user_id = get_current_user_id();
    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-jobpost-nonce', 'security');



// Insert the post into the database
    if (isset($_POST['postid']) && $_POST['postid'] > 0) {
        $job_post = array(
            'post_title' => wp_strip_all_tags($_POST['post_title']),
            'post_content' => $_POST['post_content'],
            'post_status' => 'publish',
            'ID' => $_POST['postid']
        );
        $post_id = wp_update_post($job_post);
    } else {
        $job_post = array(
            'post_title' => wp_strip_all_tags($_POST['post_title']),
            'post_content' => $_POST['post_content'],
            'post_status' => 'publish',
            'post_author' => $user_id,
            'post_type' => 'jobs'
        );
        $post_id = wp_insert_post($job_post);
    }



    if (isset($_POST['job_type']))
        wp_set_post_terms($post_id, $_POST['job_type'], 'job-type');

    if (isset($_POST['job_category']))
        wp_set_post_terms($post_id, $_POST['job_category'], 'job-category');

    if (isset($_POST['job_currency']))
        wp_set_post_terms($post_id, $_POST['job_currency'], 'currency');

    if (isset($_POST['job_salary']))
        wp_set_post_terms($post_id, $_POST['job_salary'], 'salary');

    if (isset($_POST['job_industry']))
        wp_set_post_terms($post_id, $_POST['job_industry'], 'industries');

    if (isset($_POST['job_languages']))
        wp_set_post_terms($post_id, $_POST['job_languages'], 'language');

    if (isset($_POST['job_experience']))
        wp_set_post_terms($post_id, $_POST['job_experience'], 'experience');

    if (isset($_POST['job_gender']))
        wp_set_post_terms($post_id, $_POST['job_gender'], 'gender');

    if (isset($_POST['job_qualification']))
        wp_set_post_terms($post_id, $_POST['job_qualification'], 'qualification');

    if (isset($_POST['job_country']))
        wp_set_post_terms($post_id, $_POST['job_country'], 'country');

    if (isset($_POST['job_city']))
        wp_set_post_terms($post_id, $_POST['job_city'], 'city');


    if (isset($_POST['job_latitude']))
        update_post_meta($post_id, 'job_latitude', sanitize_text_field($_POST['job_latitude']));
    if (isset($_POST['job_longitude']))
        update_post_meta($post_id, 'job_longitude', sanitize_text_field($_POST['job_longitude']));


    if (isset($_POST['job_enddate']))
        update_post_meta($post_id, 'job_enddate', sanitize_text_field($_POST['job_enddate']));

    if (isset($_POST['job_address']))
        update_post_meta($post_id, 'job_address', sanitize_text_field($_POST['job_address']));

    if (isset($_POST['job_featured']))
        update_post_meta($post_id, 'job_featured', sanitize_text_field($_POST['job_featured']));


    if (isset($_POST['job_package'])) {
        $package = get_metadata_by_mid('user', $_POST['job_package']);
        $packagearray = json_decode($package->meta_value);

        $newarray = array('package_name' => $packagearray->package_name,
            'transaction_id' => $packagearray->transaction_id,
            'order_id' => $packagearray->order_id,
            'package_expire' => $packagearray->package_expire,
            'package_listing' => $packagearray->package_listing,
            'package_display_day' => $packagearray->package_display_day,
            'featured' => $_POST['job_featured'] ? ($packagearray->featured - 1) : $packagearray->featured,
            'package_listing_added' => ($packagearray->package_listing_added + 1),
            'package_listing_remaining' => ($packagearray->package_listing_remaining - 1)
        );

        $newarraystring = json_encode($newarray);
        update_metadata_by_mid('user', $_POST['job_package'], $newarraystring);

        $expirydays = $packagearray->package_display_day;
        $wpDateFormat = get_option('date_format');
        $expirydate = date($wpDateFormat, strtotime(date($wpDateFormat) . ' + ' . $expirydays . ' days'));
        if (isset($_POST['job_expire'])) {
            update_post_meta($post_id, 'job_expire', sanitize_text_field($_POST['job_expire']));
        } else {
            update_post_meta($post_id, 'job_expire', $expirydate);
        }
        $enddate = date("Y-m-d", strtotime(date("Y-m-d") . ' + ' . $expirydays . ' days'));

        update_post_meta($post_id, 'job_end', $enddate);
    }
    update_post_meta($post_id, 'job_status', 'active');
    if (isset($_POST['postid']) && $_POST['postid'] > 0) {
        echo json_encode(array('message' => __('Job Updated Successfully.', 'jxpress-portal', 'jxpress-portal')));
    } else {
        echo json_encode(array('message' => __('Job Added Successfully.', 'jxpress-portal', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_deleteemployerjob', 'jxpress_deleteemployerjob');
add_action('wp_ajax_deleteemployerjob', 'jxpress_deleteemployerjob');

function jxpress_deleteemployerjob() {
    global $current_user;
    $user_id = get_current_user_id();
    if (isset($_POST['jobid'])) {
        $post = get_post($_POST['jobid']);
        if ($post->post_author == $user_id) {
            wp_trash_post($_POST['jobid']);
            echo json_encode(array('status' => 'removed', 'message' => __('Job deleted', 'jxpress-portal')));
        }
    }
    die();
}

add_action('wp_ajax_nopriv_deletecandidateapplication', 'jxpress_deletecandidateapplication');
add_action('wp_ajax_deletecandidateapplication', 'jxpress_deletecandidateapplication');

function jxpress_deletecandidateapplication() {
    global $current_user;
    $user_id = get_current_user_id();
    if (isset($_POST['jobid'])) {
        $post = get_post($_POST['jobid']);
        wp_trash_post($_POST['jobid']);
        echo json_encode(array('status' => 'removed', 'message' => __('Application deleted', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_changejobstatus', 'jxpress_changejobstatus');
add_action('wp_ajax_changejobstatus', 'jxpress_changejobstatus');

function jxpress_changejobstatus() {
    global $current_user;
    $user_id = get_current_user_id();
    if (isset($_POST['jobid'])) {
        $post = get_post($_POST['jobid']);
        if ($post->post_author == $user_id && isset($_POST['status'])) {
            update_post_meta( $_POST['jobid'], 'job_status', $_POST['status'] );
            if ( $_POST['status'] == 'inactive' ) {
                wp_update_post( wp_slash( array(
                    'ID'          => $_POST['jobid'],
                    'post_status' => 'draft',
                ) ) );
                echo json_encode( array('status' => 'success', 'message' => esc_html__('Job is Inactive now', 'jxpress-portal') ) );
            } else {
                wp_update_post( wp_slash( array(
                    'ID'          => $_POST['jobid'],
                    'post_status' => 'publish',
                ) ) );
                echo json_encode( array('status' => 'success', 'message' => esc_html__('Job is Active now', 'jxpress-portal') ) );
            }
            
        }
    }
    die();
}


add_action('wp_ajax_nopriv_shortlistresume', 'jxpress_shortlistresume');
add_action('wp_ajax_shortlistresume', 'jxpress_shortlistresume');

function jxpress_shortlistresume() {
    global $current_user;
    $user_id = get_current_user_id();
    if (is_user_logged_in() && isset($_POST['candidateid']) && (jxpress_userrole_exist('employer') || jxpress_userrole_exist('administrator'))) {
        $args = array(
            'meta_key' => 'candidate_shortlist',
            'meta_value' => $_POST['candidateid'],
            'meta_compare' => '=',
            'include' => array($user_id)
        );
        $user_query = new WP_User_Query($args);
        $authors = $user_query->get_results();
        if (!empty($authors)) {
            delete_user_meta($user_id, 'candidate_shortlist', $_POST['candidateid']);
            echo json_encode(array('status' => 'removed', 'message' => __('Resume removed from shortlist', 'jxpress-portal')));
        } else {
            add_user_meta($user_id, 'candidate_shortlist', sanitize_text_field($_POST['candidateid']));
            echo json_encode(array('status' => 'added', 'message' => __('Resume added to shortlist', 'jxpress-portal')));
        }
    } 
	elseif (is_user_logged_in() && jxpress_userrole_exist('candidate')) { 
	 echo json_encode(array('status' => 'login', 'message' => __('Oops! Login as employer for shortlist', 'jxpress-portal')));	
	}	
	else {
        echo json_encode(array('status' => 'login', 'message' => __('Must login for shortlist', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_shortlistjob', 'jxpress_shortlistjob');
add_action('wp_ajax_shortlistjob', 'jxpress_shortlistjob');

function jxpress_shortlistjob() {
    global $current_user;
    $user_id = get_current_user_id();
    if (is_user_logged_in() && isset($_POST['candidateid']) && (jxpress_userrole_exist('candidate') || jxpress_userrole_exist('administrator'))) {
        $args = array(
            'meta_key' => 'job_shortlist',
            'meta_value' => $_POST['candidateid'],
            'meta_compare' => '=',
            'include' => array($user_id)
        );
        $user_query = new WP_User_Query($args);
        $authors = $user_query->get_results();
        if (!empty($authors)) {
            delete_user_meta($user_id, 'job_shortlist', $_POST['candidateid']);
            echo json_encode(array('status' => 'removed', 'message' => __('Job removed from shortlist', 'jxpress-portal')));
        } else {
            add_user_meta($user_id, 'job_shortlist', sanitize_text_field($_POST['candidateid']));
            echo json_encode(array('status' => 'added', 'message' => __('Job added to shortlist', 'jxpress-portal')));
        }
    }
	elseif (is_user_logged_in() && jxpress_userrole_exist('employer')) { 
	 echo json_encode(array('status' => 'login', 'message' => __('Oops! Login as Candidate for shortlist', 'jxpress-portal')));	
	}	
	else {
        echo json_encode(array('status' => 'login', 'message' => __('Must login for shortlist', 'jxpress-portal')));
    }
    die();
}

add_action('wp_ajax_nopriv_usermessage', 'jxpress_usermessage');
add_action('wp_ajax_usermessage', 'jxpress_usermessage');

function jxpress_usermessage() {
    if (isset($_POST['uemail']))
        $email_to = $_POST['uemail'];
    $email_message = '';

    if (isset($_POST['u_name']))
        $email_message .= __('Full Name: ') . $_POST['u_name'] . "<br/>";

    if (isset($_POST['u_email']))
        $email_message .= __('Email: ') . $_POST['u_email'] . "<br/>";

    if (isset($_POST['u_phone']))
        $email_message .= __('Phone: ') . $_POST['u_phone'] . "<br/>";

    if (isset($_POST['u_message']))
        $email_message .= __('Message: ') . $_POST['u_message'] . "<br/>";

    if (isset($_POST['subject']))
        $email_subject .= $_POST['subject'];

    $headers = 'From: ' . $_POST['u_email'] . "\r\n" .
            'Reply-To: ' . $_POST['u_email'] . "\r\n" .
            'X-Mailer: PHP/' . phpversion();
    if (wp_mail($email_to, $email_subject, $email_message, $headers)) {
        echo json_encode(array('message' => __('Message sent successfully', 'jxpress-portal')));
    } else {
        echo json_encode(array('message' => __('Something wrong please try again', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_jobapply', 'jxpress_jobapply');
add_action('wp_ajax_jobapply', 'jxpress_jobapply');

function jxpress_jobapply() {

    global $current_user;
    $user_id = get_current_user_id();
    $job_post = array(
        'post_title' => wp_strip_all_tags($_POST['u_name']),
        'post_content' => $_POST['u_message'],
        'post_status' => 'publish',
        'post_author' => $user_id,
        'post_type' => 'applications'
    );
    $post_id = wp_insert_post($job_post);


    if (!function_exists('wp_handle_upload')) {
        require_once( ABSPATH . 'wp-admin/includes/file.php' );
    }

    if (!empty($_FILES['user_cv']["name"])) {
        $file_data = isset($_FILES) ? $_FILES : array();
        $cv = wp_handle_upload($_FILES['user_cv'], array(
            'mimes' => array(
                'doc' => 'application/msword',
                'docx' => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
                'pdf' => 'application/pdf',
                'rtf' => 'application/rtf',
            ),
            'test_form' => false
        ));

        if (!empty($cv['url'])) {

            update_post_meta($post_id, 'allication_cv', sanitize_text_field($cv['url']));
            $attachments = array($cv['url']);
        }
    }
    update_post_meta($post_id, 'allication_email', sanitize_text_field($_POST['u_email']));
    update_post_meta($post_id, 'allication_phone', sanitize_text_field($_POST['u_phone']));
    update_post_meta($post_id, 'allication_jobid', sanitize_text_field($_POST['jobid']));
    if (isset($_POST['uemail']))
        $email_to = $_POST['uemail'];
    $email_message = '';

    if (isset($_POST['u_name']))
        $email_message .= __('Full Name: ') . $_POST['u_name'] . "\n";



    if (isset($_POST['u_email']))
        $email_message .= __('Email: ') . $_POST['u_email'] . "\n";

    if (isset($_POST['u_phone']))
        $email_message .= __('Phone: ') . $_POST['u_phone'] . "\n";

    if (isset($_POST['u_message']))
        $email_message .= __('Message: ') . $_POST['u_message'] . "\n";




    $email_subject = __('Aplly for Job ') . get_the_title($_POST['jobid']);
    $headers = 'From: ' . $_POST['u_email'] . "\r\n" .
            'Reply-To: ' . $_POST['u_email'] . "\r\n" .
            'X-Mailer: PHP/' . phpversion();
    if (wp_mail($email_to, $email_subject, $email_message, $headers, $attachments)) {
        echo json_encode(array('message' => __('Applied successfully', 'jxpress-portal')));
    } else {
        echo json_encode(array('message' => __('Something wrong please try again', 'jxpress-portal')));
    }


    die();
}

add_action('wp_ajax_nopriv_add_jobalert', 'jxpress_add_jobalert');
add_action('wp_ajax_add_jobalert', 'jxpress_add_jobalert');

function jxpress_add_jobalert() {

    global $current_user;
    $user_id = get_current_user_id();
    $job_post = array(
        'post_title' => wp_strip_all_tags($_POST['alerts_name']),
        'post_status' => 'publish',
        'post_author' => $user_id,
        'post_type' => 'job-alerts'
    );


    if (is_user_logged_in()) {

        $post_id = wp_insert_post($job_post);
        update_post_meta($post_id, 'alert_email', sanitize_text_field($_POST['alerts_email']));


        $searchquesry = json_decode(stripslashes($_POST['search_query']));
        if (isset($searchquesry->job_city) && !empty($searchquesry->job_city)) {
            $val = get_term_by('slug', $searchquesry->job_city, 'city');
            wp_set_post_terms($post_id, $val->term_id, 'city');
        }

        if (isset($searchquesry->job_category)) {
            foreach ($searchquesry->job_category as $values) {
                $val = get_term_by('slug', $values, 'job-category');
                wp_set_post_terms($post_id, $val->term_id, 'job-category');
            }
        }

        if (isset($searchquesry->job_experience)) {
            foreach ($searchquesry->job_experience as $values) {
                $val = get_term_by('slug', $values, 'experience');
                wp_set_post_terms($post_id, $val->term_id, 'experience');
            }
        }

        if (isset($searchquesry->job_qualification)) {
            foreach ($searchquesry->job_qualification as $values) {
                $val = get_term_by('slug', $values, 'qualification');
                wp_set_post_terms($post_id, $val->term_id, 'qualification');
            }
        }

        if (isset($searchquesry->job_language)) {
            foreach ($searchquesry->job_language as $values) {
                $val = get_term_by('slug', $values, 'language');
                wp_set_post_terms($post_id, $val->term_id, 'language');
            }
        }

        if (isset($searchquesry->job_salary)) {
            foreach ($searchquesry->job_salary as $values) {
                $val = get_term_by('slug', $values, 'salary');
                wp_set_post_terms($post_id, $val->term_id, 'salary');
            }
        }


        if (isset($searchquesry->job_type)) {
            foreach ($searchquesry->job_type as $values) {
                $val = get_term_by('slug', $values, 'job-type');
                wp_set_post_terms($post_id, $val->term_id, 'job-type');
            }
        }


        if (isset($searchquesry->job_industry)) {
            foreach ($searchquesry->job_industry as $values) {
                $val = get_term_by('slug', $values, 'industries');

                wp_set_post_terms($post_id, $val->term_id, 'industries');
            }
        }

        if (isset($searchquesry->job_gender)) {
            foreach ($searchquesry->job_gender as $values) {
                $val = get_term_by('slug', $values, 'gender');
                wp_set_post_terms($post_id, $val->term_id, 'gender');
            }
        }


        echo json_encode(array('message' => __('Alert Added', 'jxpress-portal')));
    } else {
        echo json_encode(array('message' => __('Must login for add alert', 'jxpress-portal')));
    }



    die();
}

add_action('wp_ajax_nopriv_delete_alert', 'jxpress_delete_alert');
add_action('wp_ajax_delete_alert', 'jxpress_delete_alert');

function jxpress_delete_alert() {
    global $current_user;
    $user_id = get_current_user_id();
    if (isset($_POST['id'])) {
        $post = get_post($_POST['id']);
        wp_trash_post($_POST['id']);
        echo json_encode(array('status' => 'removed', 'message' => __('Alert deleted', 'jxpress-portal')));
    }
    die();
}

?>